@@ -4,8 +4,15 @@ and normalization product descriptions.
 """
 from typing import Union, Optional, Dict
 import pandas as pd  # type: ignore
-from . import Finder
-from . import Normalizer
+try:
+    from . import Finder
+    from . import Normalizer
+except ImportError:
+    from finder import Finder
+    from normalizer import Normalizer
+except ModuleNotFoundError:
+    from .finder import Finder
+    from .normalizer import Normalizer
 
 
 # pylint: disable=too-few-public-methods
